package com.starbuds.server.service.feed.dao;

import com.starbuds.server.common.pojo.db.FeedCommentDO;
import com.starbuds.server.common.pojo.feed.FeedCommentVO;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * @Author jiangxiaowei
 * @DateTime 2020-05-27 15:50:04
 * @Description 内容评论表持久层
 */
@Mapper
@Repository
public interface FeedCommentDAO {

    /**
     * 新增
     *
     * @param entity
     * @return
     */
    Long insert(FeedCommentDO entity);

    /**
     * 增加点赞数
     *
     * @param commentId
     * @param count
     * @param version
     * @return
     */
    int increaseLikeCount(@Param("commentId") Long commentId,
                          @Param("count") Integer count,
                          @Param("version") Long version);

    /**
     * 减少点赞数
     *
     * @param commentId
     * @param count
     * @param version
     * @return
     */
    int decreaseLikeCount(@Param("commentId") Long commentId,
                          @Param("count") Integer count,
                          @Param("version") Long version);

    /**
     * 增加评论数量
     *
     * @param commentId
     * @param count
     * @param version
     * @return
     */
    int increaseCommentCount(@Param("commentId") Long commentId,
                             @Param("count") Integer count,
                             @Param("version") Long version);

    /**
     * 减少评论数量
     *
     * @param commentId
     * @param count
     * @param version
     * @return
     */
    int decreaseCommentCount(@Param("commentId") Long commentId,
                             @Param("count") Integer count,
                             @Param("version") Long version);

    /**
     * 获取内容评论
     *
     * @param pageCursor
     * @param pageSize
     * @param feedId
     * @return
     */
    List<FeedCommentVO> selectByFeedId(@Param("pageCursor") int pageCursor,
                                       @Param("pageSize") int pageSize,
                                       @Param("feedId") Long feedId);


    /**
     * 根据回复id查询
     *
     * @param replyId
     * @return
     */
    List<FeedCommentVO> selectByReplyId(@Param("replyId") Long replyId);


    /**
     * 根据回复id查询
     *
     * @param replyId
     * @return
     */
    List<FeedCommentVO> selectOneByReplyId(@Param("replyId") Long replyId);

    /**
     * 根据回复id查询
     *
     * @param lastId
     * @param replyId
     * @param pageSize
     * @return
     */
    List<FeedCommentVO> selectByReplyIdPageList(@Param("lastId") Long lastId,
                                                @Param("replyId") Long replyId,
                                                @Param("pageSize") int pageSize);

    /**
     * 判断是否存在
     *
     * @param commentId
     * @return
     */
    int countById(@Param("commentId") Long commentId);

    /**
     * 根据id查询
     *
     * @param commentId
     * @return
     */
    FeedCommentDO selectById(@Param("commentId") Long commentId);

    /**
     * 获取版本
     *
     * @param commentId
     * @return
     */
    Long selectVersion(@Param("commentId") Long commentId);

    /**
     * 获取评论
     *
     * @param feedId
     * @param lastId
     * @param pageSize
     * @return
     */
    List<FeedCommentVO> selectCommentList(@Param("feedId") Long feedId,
                                          @Param("lastId") Long lastId,
                                          @Param("pageSize") int pageSize);

    /**
     * 更新状态
     *
     * @param commentId
     * @param status
     * @return
     */
    int updateStatus(@Param("commentId") Long commentId, @Param("status") Integer status);

    /**
     * 获取用户id
     *
     * @param commentId
     * @return
     */
    Long selectUserId(@Param("commentId") Long commentId);

    /**
     * 获取答复id
     *
     * @param commentId
     * @return
     */
    Long selectReplyId(@Param("commentId") Long commentId);

    /**
     * 获取内容id
     *
     * @param commentId
     * @return
     */
    Long selectFeedId(@Param("commentId") Long commentId);

    /**
     * 获取顶层id
     *
     * @param commentId
     * @return
     */
    Long selectOriReplyId(@Param("commentId") Long commentId);
}
