package com.starbuds.server.service.feed.dao;

import com.starbuds.server.common.pojo.db.FeedDO;
import com.starbuds.server.common.pojo.feed.FeedGroupByDateVO;
import com.starbuds.server.common.pojo.feed.FeedSquareVO;
import com.starbuds.server.common.pojo.feed.FeedVO;
import org.apache.ibatis.annotations.MapKey;
import org.apache.ibatis.annotations.Mapper;
import org.apache.ibatis.annotations.Param;
import org.springframework.stereotype.Repository;

import java.util.Collection;
import java.util.List;
import java.util.Map;
import java.util.Set;

/**
 * 内容
 */
@Mapper
@Repository
public interface FeedDAO {

    /**
     * 添加数据
     */
    int insert(FeedDO feed);

    /**
     * 更新数据
     */
    int update(FeedDO feed);

    /**
     * 判断是否存在
     *
     * @param feedId
     * @return
     */
    int countById(@Param("feedId") Long feedId);

    /**
     * 根据主键查询
     *
     * @param feedId
     * @return
     */
    FeedDO selectById(@Param("feedId") Long feedId);

    /**
     * 查询内容详情
     *
     * @param feedId
     * @param feedStatus
     * @param isDeleted
     * @return
     */
    FeedDO selectDetail(@Param("feedId") Long feedId,
                        @Param("feedStatus") Integer feedStatus,
                        @Param("isDeleted") Integer isDeleted);

    /**
     * 增加点赞数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int increaseLikeCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 减少点赞数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int decreaseLikeCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 增加收藏数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int increaseCollectCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 减少收藏数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int decreaseCollectCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 增加分享数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int increaseShareCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 减少分享数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int decreaseShareCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 增加评论数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int increaseCommentCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 减少评论数
     *
     * @param feedId
     * @param count
     * @param version
     * @return
     */
    int decreaseCommentCount(@Param("feedId") Long feedId, @Param("count") int count, @Param("version") Long version);

    /**
     * 获取内容
     *
     * @param lastId
     * @param pageSize
     * @param feedType
     * @param userId
     * @param isSelf
     * @return
     */
    List<FeedVO> selectFeedList(@Param("lastId") Long lastId,
                                @Param("pageSize") int pageSize,
                                @Param("feedType") Integer feedType,
                                @Param("userId") Long userId,
                                @Param("isSelf") Integer isSelf);

    /**
     * 获取用户id
     *
     * @param feedId
     * @return
     */
    Long selectUserId(@Param("feedId") Long feedId);

    /**
     * 更新删除状态
     *
     * @param feedId
     * @param isDeleted
     * @return
     */
    int updateDeleteStatus(@Param("feedId") Long feedId, @Param("isDeleted") int isDeleted);

    /**
     * 获取版本
     *
     * @param feedId
     * @return
     */
    Long selectVersion(@Param("feedId") Long feedId);

    /**
     * 更新查看数
     *
     * @param feedId
     * @param version
     * @return
     */
    int updateViewCount(@Param("feedId") Long feedId, @Param("version") Long version);

    /**
     * 获取内容类型
     *
     * @param feedId
     * @return
     */
    Integer selectFeedType(@Param("feedId") Long feedId);

    /**
     * 更新照片墙
     *
     * @param feedId
     * @param photoWall
     * @return
     */
    int updatePhotoWall(@Param("feedId") Long feedId, @Param("photoWall") Integer photoWall);

    /**
     * 获取照片墙
     *
     * @param userId
     * @return
     */
    List<String> getPhotoWalls(@Param("userId") Long userId);

    /**
     * 根据用户id获取照片墙
     *
     * @param userIds
     * @return userId:图片地址1,图片地址2
     */
    @MapKey("userId")
    Map<Long, FeedVO> selectPhotoWallByUserIds(@Param("userIds") Collection userIds);

    /**
     * 获取照片墙数量
     *
     * @param userId
     * @return
     */
    int countPhotoWall(@Param("userId") Long userId);

    /**
     * 以天为单位的内容列表
     *
     * @param pageCursor
     * @param pageSize
     * @param userId
     * @return
     */
    List<Long> selectFeedListGroupByDate(@Param("pageCursor") int pageCursor,
                                         @Param("pageSize") int pageSize,
                                         @Param("userId") Long userId,
                                         @Param("feedStatus") Integer feedStatus);

    int selectFeedListGroupByDateCount(@Param("userId") Long userId, @Param("feedStatus") Integer feedStatus);

    /**
     * 获取广场数量
     *
     * @return
     */
    int getSquareFeedCount(@Param("beginTime") Long beginTime, @Param("endTime") Long endTime);

    /**
     * 通过ID获取数据
     *
     * @param feedIds
     * @return
     */
    List<FeedSquareVO> getSquareFeedListByIds(@Param("feedIds") List<Long> feedIds);

    List<Long> getSquareFeedIdList(@Param("beginTime") Long beginTime, @Param("endTime") Long endTime);

    Long getTopFeed(@Param("now") Long now);

    /**
     * 获取最近三天发过动态的用户ID
     *
     * @param userIds
     * @param promiseTime
     * @return
     */
    List<Long> getFeedUserIds(@Param("userIds") Set<Long> userIds, @Param("promiseTime") Long promiseTime);
}
