package com.starbuds.server.service.feed.dao;

import com.starbuds.server.common.pojo.db.FeedPhotoWallDO;
import com.starbuds.server.common.pojo.feed.FeedPhotoWallVO;
import com.starbuds.server.service.feed.dao.provider.FeedPhotoWallDAOProvider;
import org.apache.ibatis.annotations.*;
import org.springframework.stereotype.Repository;

import java.util.List;

/**
 * 内容-照片墙
 *
 * @author aoe
 * @date 2021/1/29
 */
@Mapper
@Repository
public interface FeedPhotoWallDAO {

    @InsertProvider(type = FeedPhotoWallDAOProvider.class, method = "insertSql")
    int insert(FeedPhotoWallDO fpw);

    @Select("SELECT COUNT(*) FROM tb_feed_photo_wall WHERE userId = #{userId} AND isDeleted = 0")
    int selectCountByUserId(Long userId);

    /**
     * 查询照片墙列表
     *
     * @param userId
     * @param status
     * @return
     */
    @SelectProvider(type = FeedPhotoWallDAOProvider.class, method = "selectList")
    List<FeedPhotoWallVO> selectList(@Param("userId") Long userId, @Param("status") Integer status);

    /**
     * 查询照片墙信息
     *
     * @param feedPhotoWallId
     * @return
     */
    @SelectProvider(type = FeedPhotoWallDAOProvider.class, method = "selectById")
    FeedPhotoWallDO selectById(@Param("feedPhotoWallId") Long feedPhotoWallId);

    /**
     * 根据id查询数量
     *
     * @param feedPhotoWallId
     * @return
     */
    @SelectProvider(type = FeedPhotoWallDAOProvider.class, method = "selectCountById")
    int selectCountById(@Param("feedPhotoWallId") Long feedPhotoWallId);

    /**
     * 更新
     *
     * @param fpw
     * @return
     */
    @UpdateProvider(type = FeedPhotoWallDAOProvider.class, method = "update")
    int update(FeedPhotoWallDO fpw);

    /**
     * 删除相册
     *
     * @param userId
     * @param feedPhotoWallId
     * @return
     */
    @UpdateProvider(type = FeedPhotoWallDAOProvider.class, method = "delete")
    int delete(@Param("userId") Long userId,
               @Param("feedPhotoWallId") Long feedPhotoWallId,
               @Param("updateTime") Long updateTime
    );
}
