package com.starbuds.server.service.feed.dao.provider;

import com.starbuds.server.common.constant.feed.FeedStatusEnum;
import com.starbuds.server.common.pojo.db.FeedPhotoWallDO;
import org.apache.ibatis.jdbc.SQL;

import java.util.Map;

/**
 * 照片墙SQL实现
 *
 * @author aoe
 * @date 2021/1/29
 */
public class FeedPhotoWallDAOProvider {

    private final String TB_FEED_PHOTO_WALL = "tb_feed_photo_wall";

    public String insertSql() {
        String sql = new SQL()
                .INSERT_INTO(TB_FEED_PHOTO_WALL)
                .VALUES("feedPhotoWallId", "#{feedPhotoWallId}")
                .VALUES("userId", "#{userId}")
                .VALUES("url", "#{url}")
                .VALUES("sort", "#{sort}")
                .VALUES("status", "#{status}")
                .VALUES("adminId", "#{adminId}")
                .VALUES("auditMsg", "#{auditMsg}")
                .VALUES("version", "#{version}")
                .VALUES("createTime", "#{createTime}")
                .VALUES("updateTime", "#{updateTime}")
                .VALUES("isDeleted", "#{isDeleted}")
                .toString();
        return sql;
    }

    public String selectList(Map<String, Object> param) {
        SQL sql = new SQL()
                .SELECT("feedPhotoWallId", "userId", "url", "status", "auditMsg", "createTime", "updateTime")
                .FROM(TB_FEED_PHOTO_WALL)
                .WHERE("userId = #{userId}")
                .WHERE("isDeleted = 0");
        if (param.get("status") != null) {
            sql.WHERE("status = #{status}");
        }

        return sql.toString();
    }

    public String selectById() {
        SQL sql = new SQL()
                .SELECT("feedPhotoWallId", "userId", "url", "status", "auditMsg", "createTime", "updateTime")
                .FROM(TB_FEED_PHOTO_WALL)
                .WHERE("feedPhotoWallId = #{feedPhotoWallId}")
                .WHERE("isDeleted = 0");

        return sql.toString();
    }

    public String selectCountById() {
        SQL sql = new SQL()
                .SELECT("COUNT(*)")
                .FROM(TB_FEED_PHOTO_WALL)
                .WHERE("feedPhotoWallId = #{feedPhotoWallId}")
                .WHERE("isDeleted = 0");

        return sql.toString();
    }

    public String update(FeedPhotoWallDO fpw) {
        SQL sql = new SQL()
                .UPDATE(TB_FEED_PHOTO_WALL)
                .SET("status = #{status}")
                .SET("updateTime = #{updateTime}");
        if (fpw.getSort() != null) {
            sql.SET("sort = #{sort}");
        }
        if (fpw.getAdminId() != null) {
            sql.SET("adminId = #{adminId}");
        }
        if (fpw.getAuditMsg() != null) {
            sql.SET("auditMsg = #{auditMsg}");
        }
        if (fpw.getVersion() != null) {
            sql.SET("version = #{version}");
        }
        if (fpw.getIsDeleted() != null) {
            sql.SET("isDeleted = #{isDeleted}");
        }
        sql.WHERE("feedPhotoWallId = #{feedPhotoWallId}")
                .WHERE("status = " + FeedStatusEnum.AUDIT_ROBOT.value());

        return sql.toString();
    }

    public String delete() {
        SQL sql = new SQL()
                .UPDATE(TB_FEED_PHOTO_WALL)
                .SET("isDeleted = 1")
                .SET("updateTime = #{updateTime}")
                .WHERE("feedPhotoWallId = #{feedPhotoWallId}")
                .WHERE("userId = #{userId}");
        return sql.toString();
    }
}
