package com.starbuds.server.service.feed.rocket.handler;

import com.starbuds.server.common.constant.data.PlayTopTypeEnum;
import com.starbuds.server.common.constant.feed.FeedCreateBusinessEnum;
import com.starbuds.server.common.constant.feed.FeedTypeEnum;
import com.starbuds.server.common.constant.statistics.StatPlatformTypeEnum;
import com.starbuds.server.common.pojo.db.PlayTopDO;
import com.starbuds.server.common.pojo.mq.QueueFeedCreateMsg;
import com.starbuds.server.common.pojo.mq.QueueFeedViewMsg;
import com.starbuds.server.common.service.core.IdentityService;
import com.starbuds.server.common.service.data.DataService;
import com.starbuds.server.common.service.statistics.StatPlatformService;
import com.starbuds.server.service.feed.dao.FeedDAO;
import com.starbuds.server.service.feed.provider.ImageSyncScanProvider;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.apache.dubbo.config.annotation.Reference;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.scheduling.annotation.Async;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.math.BigDecimal;
import java.util.Arrays;

/**
 * 正常消息处理
 *
 * @author aoe
 * @date 2020/5/29
 */
@Component
@Slf4j
public class NormalMsgHandler {

    @Reference(version = "1.0.0")
    StatPlatformService statPlatformService;

    @Reference(version = "1.0.0")
    IdentityService identityService;

    @Reference(version = "1.0.0")
    DataService dataService;

    @Autowired
    private ImageSyncScanProvider imageSyncScanProvider;
    @Resource
    FeedDAO feedDAO;

    @Async
    public void handleFeedCreate(QueueFeedCreateMsg msg) {
        log.info("收到内容系统创建消息 {}", msg);
        if (msg == null) {
            log.error("收到内容系统创建消息为 null，不能进行审核");
            return;
        }
        if (msg.getFeedId() == null || StringUtils.isBlank(msg.getUrl())) {
            log.error("收到内容系统创建消息存在 null 值，不能进行审核 msg={}", msg);
            return;
        }

        Long channelId = msg.getChannelId();
        FeedTypeEnum typeEnum = FeedTypeEnum.toEnum(msg.getFeedType());

        statPlatformService.addPlatformStat(channelId, StatPlatformTypeEnum.FEED_UPLOAD, BigDecimal.ONE);

        FeedCreateBusinessEnum businessEnum = msg.getBusinessEnum();
        // 是否添加陪玩头条（陪玩 改 开黑）
        boolean addPlayTop = false;
        // 默认添加头条  照片墙除外
        if (businessEnum == null) {
            addPlayTop = true;
        } else {
            switch (businessEnum) {
                case PHOTO_WALL:
                    break;
                default:
                    addPlayTop = true;
                    break;
            }
        }
        // 陪玩头条（陪玩 改 开黑）
        if (addPlayTop) {
            PlayTopDO topDO = new PlayTopDO();
            topDO.setTopId(identityService.getId());
            topDO.setTopType(PlayTopTypeEnum.RELEASE_NEWS.getCode());
            topDO.setUserId(msg.getUserId());
            topDO.setCreateTime(msg.getTimestamp());
            dataService.addPlayTop(topDO);
        }

        log.info("提交内容审核");
        switch (typeEnum) {
            case PHOTO:
                statPlatformService.addPlatformStat(channelId, StatPlatformTypeEnum.PHOTO_UPLOAD, BigDecimal.ONE);
                String urls = msg.getUrl();
                if (StringUtils.isBlank(urls)) {
                    return;
                }
                Arrays.stream(urls.split(","))
                        .forEach(url -> {
                            imageSyncScanProvider.scanImage(msg.getFeedId(), url, msg.getChannelId(),
                                    msg.getBusinessEnum());
                        });
                break;
            case VIDEO:
                statPlatformService.addPlatformStat(channelId, StatPlatformTypeEnum.VIDEO_UPLOAD, BigDecimal.ONE);
                break;
        }

    }

    /**
     * 内容浏览
     *
     * @param msg
     */
    public void handleFeedView(QueueFeedViewMsg msg) {

        Long feedId = msg.getFeedId();
        Long channelId = msg.getChannelId();
        Integer feedType = msg.getFeedType();

        if (feedDAO.updateViewCount(feedId, feedDAO.selectVersion(feedId)) > 0) {

            statPlatformService.addPlatformStat(channelId, StatPlatformTypeEnum.FEED_VIEW, BigDecimal.ONE);

            FeedTypeEnum typeEnum = FeedTypeEnum.toEnum(feedType);
            switch (typeEnum) {
                case PHOTO:
                    statPlatformService.addPlatformStat(channelId, StatPlatformTypeEnum.PHOTO_VIEW, BigDecimal.ONE);
                    break;
                case VIDEO:
                    statPlatformService.addPlatformStat(channelId, StatPlatformTypeEnum.VIDEO_VIEW, BigDecimal.ONE);
                    break;
                case TEXT:
                    break;
            }
            return;
        }
        handleFeedView(msg);
    }
}
